<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ReportExtendedObjects.xsl"/>
	
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- The code here is pulled from early implementations of the report. 					-->
	<!-- This WILL produce a report, but it will not be as robust and polished as Archive. -->
	<xsl:template match="optimreport:ExtractReport | optimreport:extractReport">
		<xsl:param name="display">True</xsl:param>

		<xsl:variable name="displayStyle">
			<xsl:choose>
				<xsl:when test="$display='True'">
					<xsl:text></xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>display:none</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!--BEGIN SUMMARY SECTION-->
		<xsl:if test="optimreport:summary[@*]">
			<xsl:apply-templates select="optimreport:summary">
				<xsl:with-param name="display" select="$display"/>
			</xsl:apply-templates>
		</xsl:if>
		<!--END SUMMARY SECTION-->
		
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>

		<!-- Process details title bar -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">
				<xsl:choose>
					<xsl:when test="$display='True'">
						<xsl:text>false</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>true</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="isInnerReport">false</xsl:with-param>
		</xsl:call-template>
		
		<!-- Content section -->
		<div id="details_container" class="section_container details_container_class" style="{$displayStyle}" inAllAction="true">
			<table class="archive_process_details">
				
				<!-- Call access definition template to determine if we need to display the full section -->
				<xsl:apply-templates select="optimreport:localAccessDefinition"/>
				<xsl:apply-templates select="optimreport:accessDefinition" />

				<!-- Archive File -->
				<xsl:apply-templates select="optimreport:extractFile">
					<xsl:with-param name="tablename">
						<xsl:text>Extract file</xsl:text>
					</xsl:with-param>
				</xsl:apply-templates>
				
				<!-- File Attachments section-->
				<xsl:apply-templates select="optimreport:fileAttachments">
					<xsl:with-param name="id">archive_fileattachments_rows</xsl:with-param>
					<xsl:with-param name="classname">archive_fileattachments_rows</xsl:with-param>
					<xsl:with-param name="inAllAction">false</xsl:with-param>
				</xsl:apply-templates>
			</table>
			
			<!-- Apply the Entities Section -->
			<xsl:if test="optimreport:entities/optimreport:entity">
				<xsl:call-template name="extractEntities" />
			</xsl:if>
		</div>
		<xsl:if test="optimreport:extendedObjectTypes/*">
			<xsl:apply-templates select="optimreport:extendedObjectTypes" />
		</xsl:if>
		<xsl:if test="optimreport:statistics/optimreport:statistic">
			<xsl:apply-templates select="optimreport:statistics" />
		</xsl:if>
		<xsl:if test="optimreport:relationships/optimreport:relationship">
			<xsl:apply-templates select="optimreport:relationships" />
		</xsl:if>
		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:for-each select="optimreport:ConvertReport">
			<!-- Set up inner report anchor -->
			<xsl:call-template name="anchorSetup">
				<xsl:with-param name="name">innerreport</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="sectionSeperator">
				<xsl:with-param name="sectionName">Convert Report</xsl:with-param>
			</xsl:call-template>
			<xsl:apply-templates select=".">
				<xsl:with-param name="display">
					<xsl:text>False</xsl:text>
				</xsl:with-param>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>
	<!-- END Extract REPORT MAIN -->

		<!-- BEGIN entities section -->
	<xsl:template name="extractEntities">
		<table class="entity_details">
			<tr isTitle="yes">
				<th style="min-width: 125px;">
					<center>
						<xsl:text>Name</xsl:text>
					</center>
				</th>
				<td >
					<center>
						<xsl:text>Status</xsl:text>
					</center>
				</td>
				<td >
					<center>
						<xsl:text>Extracted</xsl:text>
					</center>
				</td>
				<td >
					<center>
						<xsl:text>Failed</xsl:text>
					</center>
				</td>
				<td >
					<center>
						<xsl:text>Data byte count</xsl:text>
					</center>
				</td>
				<td >
					<center>
						<xsl:text>Type</xsl:text>
					</center>
				</td>
			</tr>

			<xsl:for-each select="optimreport:entities/optimreport:entity">
				<tr swaparrow="true">
					<th class="drop_down_hover entity_rows" onClick="toggleRows('{generate-id()}_class', event); SwapByClass('blockArrow', '{generate-id()}', event)">
						<xsl:call-template name="arrow">
							<xsl:with-param name="id" select="concat(generate-id(), '_arrow')" />
							<xsl:with-param name="isExpand">false</xsl:with-param>
						</xsl:call-template>
						<xsl:text>&#160;&#160;&#160;</xsl:text>
						<xsl:call-template name="stringCheck">
							<xsl:with-param name="value" select="@name"/>
						</xsl:call-template>
					</th>
					<td>
						<xsl:call-template name="stringCheck">
							<xsl:with-param name="value" select="@status"/>
						</xsl:call-template>
					</td>
					<td class="rightAlignRow">
						<xsl:choose>
							<xsl:when test="string-length(@recordCount) = 0">
								<xsl:text>0</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test='not(number(@recordCount) = number(@recordCount))'>
										<xsl:text>(Unavailable)</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="numberFormat">
											<xsl:with-param name="number" select="@recordCount"/>
											<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td class="rightAlignRow">
						<xsl:choose>
							<xsl:when test="string-length(@failed) = 0">
								<xsl:text>0</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test='not(number(@failed) = number(@failed))'>
										<xsl:text>(Unavailable)</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="numberFormat">
											<xsl:with-param name="number" select="@failed"/>
											<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td class="rightAlignRow">
						<xsl:choose>
							<xsl:when test="string-length(@dataByteCount) = 0">
								<xsl:text>0</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test='not(number(@dataByteCount) = number(@dataByteCount))'>
										<xsl:text>(Unavailable)</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="numberFormat">
											<xsl:with-param name="number" select="@dataByteCount"/>
											<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td>
						<xsl:call-template name="stringCheck">
							<xsl:with-param name="value" select="@type"/>
						</xsl:call-template>
					</td>
				</tr>
				<!-- These subsections are for Archive only? -->
				<tr id="{generate-id()}" class="{generate-id()}_class" style="display:none;" inAllAction="true">
						<th class="entity_row">
							<xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
							<xsl:text>Compression status</xsl:text>
						</th>
						<td>
							<xsl:value-of select="optimreport:compression/@status"/>
						</td>
					</tr>
				<xsl:choose>
					<xsl:when test="optimreport:compression/@status='Enabled'">
						<tr id="{generate-id()}" class="{generate-id()}_class" style="display:none;" inAllAction="true">
							<th class="entity_row">
								<xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
								<xsl:text>Compression ratio</xsl:text>
							</th>
							<td>
								<xsl:value-of select="optimreport:compression/@value" />
								<xsl:text>%</xsl:text>
							</td>
						</tr>
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</table>
	</xsl:template>
	<!-- END entities section -->
	
</xsl:stylesheet>

